@@ -4,6 +4,7 @@ import importlib
 from pathlib import Path
 from typing import TYPE_CHECKING
 
+from astro.options import LoadOptionsList
 from astro.utils.path import get_class_name, get_dict_with_module_names_to_dot_notations
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -14,6 +15,8 @@ DEFAULT_CONN_TYPE_TO_MODULE_PATH = get_dict_with_module_names_to_dot_notations(P
 CUSTOM_CONN_TYPE_TO_MODULE_PATH = {
     "gcpbigquery": DEFAULT_CONN_TYPE_TO_MODULE_PATH["bigquery"],
     "google_cloud_platform": DEFAULT_CONN_TYPE_TO_MODULE_PATH["bigquery"],
+    "databricks": "astro.databases.databricks.delta",
+    "delta": "astro.databases.databricks.delta",
 }
 CONN_TYPE_TO_MODULE_PATH = {
     **DEFAULT_CONN_TYPE_TO_MODULE_PATH,
@@ -23,8 +26,7 @@ SUPPORTED_DATABASES = set(DEFAULT_CONN_TYPE_TO_MODULE_PATH.keys())
 
 
 def create_database(
-    conn_id: str,
-    table: BaseTable | None = None,
+    conn_id: str, table: BaseTable | None = None, load_options_list: LoadOptionsList | None = None
 ) -> BaseDatabase:
     """
     Given a conn_id, return the associated Database class.
@@ -38,5 +40,7 @@ def create_database(
     module_path = CONN_TYPE_TO_MODULE_PATH[conn_type]
     module = importlib.import_module(module_path)
     class_name = get_class_name(module_ref=module, suffix="Database")
-    database: BaseDatabase = getattr(module, class_name)(conn_id, table)
+    database_class = getattr(module, class_name)
+    load_options = load_options_list and load_options_list.get(database_class)
+    database: BaseDatabase = database_class(conn_id, table, load_options=load_options)
     return database
