@@ -20,3 +20,7 @@ class DatabaseCustomError(ValueError, AttributeError):
     Inappropriate argument value (of correct type) or attribute
     not found while running query. while running query
     """
+
+
+class PermissionNotSetError(Exception):
+    """Raised if a permission to files present in locations are not accessible"""
