@@ -4,10 +4,19 @@ from airflow.models.xcom_arg import XComArg
 
 from astro.sql.operators.append import AppendOperator, append
 from astro.sql.operators.cleanup import CleanupOperator, cleanup
+from astro.sql.operators.data_validations.ColumnCheckOperator import (  # skipcq: PY-W2000
+    ColumnCheckOperator,
+    column_check,
+)
+from astro.sql.operators.data_validations.SQLCheckOperator import (  # skipcq: PY-W2000
+    SQLCheckOperator,
+    sql_check,
+)
 from astro.sql.operators.dataframe import DataframeOperator, dataframe
 from astro.sql.operators.drop import DropTableOperator, drop_table
 from astro.sql.operators.export_file import ExportFileOperator, export_file
 from astro.sql.operators.export_table_to_file import ExportTableToFileOperator, export_table_to_file
+from astro.sql.operators.export_to_file import ExportToFileOperator, export_to_file
 from astro.sql.operators.load_file import LoadFileOperator, load_file
 from astro.sql.operators.merge import MergeOperator, merge
 from astro.sql.operators.raw_sql import RawSQLOperator, run_raw_sql
@@ -27,6 +36,8 @@ __all__ = [
     "export_file",
     "ExportTableToFileOperator",
     "export_table_to_file",
+    "ExportToFileOperator",
+    "export_to_file",
     "get_value_list",
     "LoadFileOperator",
     "load_file",
